/*
  This file is part of quick-memo
  Copyright (C) 2014 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.0
import Ubuntu.Components 1.1
import Ubuntu.Components.ListItems 1.0 as ListItem
import Ubuntu.Components.Popups 1.0

/* TODO: Not now, but in future, this page should be removed.
    MainPage should provide a ListView.header which user can quickly add notes with.
    For more powerful note-adding, we should use MemoPage instead.*/
Page {
    id: mainPage
    title: i18n.tr("Add a new memo")

    function addNote() {
        notes.addNote(addNoteTitleField.text,
                      addNoteTextField.text,
                      "" + bg.color,    // The char '#' from the hex color is not correctly parse by JSON. We add an empty string, so that it works well.
                      listManager.exportModel(),
                      pictureManager.exportModel())
        pageStack.pop()
    }

    Action {
        id: saveMemo
        text: i18n.tr("Save")
        iconName: "save"
        onTriggered: {
            var shouldISaveIt = false

            if (addNoteTitleField.text != "")
                shouldISaveIt = true

            if (addNoteTextField.text != "")
                shouldISaveIt = true

            if (listManager.exportModel().length > 0)
                shouldISaveIt = true

            if (pictureManager.exportModel().length > 0)
                shouldISaveIt = true

            if (shouldISaveIt) {
                addNote()
            } else {
                PopupUtils.open(addContentErrorDialog)
            }
        }
    }

    Action {
        id: colorToolAction
        text: i18n.tr("Change note color")
        iconSource: "../img/palette.svg"
        onTriggered: colorDialog.show()
    }

    tools: ToolbarItems {
        ToolbarButton { action: colorToolAction }
        ToolbarButton { action: saveMemo }
    }

    // Background
    Rectangle {
        id: bg
        anchors.fill: parent
        z: -10; opacity: 0.5
        color: colorDialog.selectedColor
    }

    /* MainView clips its content, so that it does not overlap the header.
       We need to bypass this, using another Rectangle that specifically overlap the header.
    */
    Rectangle {
        id: headerBg
        parent: root.header
        z: -10; opacity: 0.5

        width: root.width
        height: root.header.height
        color: bg.color
    }

    Flickable {
        id: flickable
        anchors.fill: parent

        // FIXME: Strange behaviour on contentHeight
        contentHeight: addMemo.height + units.gu(4)
        interactive: true

        // This Connections makes it possible to scroll the whole flickable properly when OSK is visible (ListManager won't be partially hidden anymore).
        Connections {
            target: Qt.inputMethod
            onVisibleChanged: {
                if (visible)
                    flickable.contentHeight = addMemo.height + units.gu(16) + Qt.inputMethod.height
                else
                    flickable.contentHeight = addMemo.height + units.gu(16) + Qt.inputMethod.height
            }
        }

        Column {
            id: addMemo
            anchors { top: parent.top; left: parent.left; right: parent.right; margins: units.gu(2) }
            spacing: units.gu(2)

            Row {
                spacing: units.gu(2)

                Label {
                    id: titleLabel
                    text: i18n.tr("Title:")
                }

                TextField {
                    id: addNoteTitleField
                    placeholderText: i18n.tr("Insert title here")
                    width: root.width - titleLabel.width - units.gu(6)
                }
            }

            Row {
                spacing: units.gu(2)

                Label {
                    id: descLabel
                    text: i18n.tr("Description:")
                }

                TextArea {
                    id: addNoteTextField
                    placeholderText: i18n.tr("Insert description here")
                    autoSize: true
                    width: root.width - descLabel.width - units.gu(6)
                }

            }

            Column {
                width: parent.width
                spacing: units.gu(1)

                Label { text: i18n.tr("Pictures:") }
                PicturesManager { id: pictureManager }
            }

            Column {
                width: parent.width
                spacing: units.gu(1)

                Label { text: i18n.tr("List: (slide an item to remove it)") }
                ListManager {
                    id: listManager
                }
            }
        }
    }

    // *** ERROR POPUPS ***
    Component {
        id: addContentErrorDialog
        Dialog {
            id: addContentError
            title: i18n.tr("Error!")
            text: i18n.tr("Please add content before saving.")

            Button {
                text: i18n.tr("OK")
                color: UbuntuColors.orange
                onClicked: {
                    PopupUtils.close(addContentError)
                    pageStack.pop();
                }
            }
        }
    }

    ColorDialog {
        id: colorDialog

        colors: ["#fdfdfd", "#e9674d", "#f0a250", "#eec34f", "#aea79f", "#95c253", "#8bbee2", "#e46f8e"]
        //askConfirmation: true
    }
}
