/*
  This file is part of quick-memo
  Copyright (C) 2014 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.0
import Ubuntu.Components 1.1

Item {
    id: rootItem

    property bool active: false

    property Page target
    property ToolbarItems tools
    property string title

    property var indexes: []
    property int count: rootItem.indexes.length

    QtObject {
        id: d
        property ToolbarItems tools
        property string title
    }

    // Provide a visual feedback when active
    Rectangle {
        id: headerBg
        parent: target.header
        z: -10

        width: target.width
        height: target.header.height
        color: "#19B6EE"   // Cyan
        visible: rootItem.active
    }

    onActiveChanged: {
        if(active) {
            // Copy current toolbar and title
            d.tools = target.tools
            d.title = target.title

            // Show new header
            target.tools = rootItem.tools
            target.title = rootItem.title

        } else {
            target.tools = d.tools
            target.title = d.title

            // Clean the model
            rootItem.indexes = []
        }
    }

    Connections {
        target: rootItem.target
        onActiveChanged: rootItem.active = false
    }

    signal indexAdded(var index)
    signal indexRemoved(var index)

    function selectUnselectItem(index) {
        for (var i=0; i<rootItem.indexes.length; i++) {
            // Search for index in the model
            if (rootItem.indexes[i] === index) {
                // That means it's already in, so remove it.
                rootItem.indexes.splice(i, 1);

                // Update count and header
                rootItem.count = rootItem.indexes.length
                target.tools = rootItem.tools
                target.title = rootItem.title

                // Return false if the index is removed.
                rootItem.indexRemoved(index)
                return false
            }
        }

        // Otherwise, the item is not in the model, so add it.
        rootItem.indexes.push(index)

        // Update count
        rootItem.count = rootItem.indexes.length
        target.tools = rootItem.tools
        target.title = rootItem.title

        // Sort indexes, so they're processed ascending if requested. This simplify the code of the functions that use this array.
        indexes.sort(function(a,b) {return a-b})


        // Return true if the index is added
        rootItem.indexAdded(index)
        return true
    }
}
