/*
  This file is part of quick-memo
  Copyright (C) 2014 Stefano Verzegnassi

    This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License 3 as published by
  the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
  along with this program. If not, see http://www.gnu.org/licenses/.
*/

import QtQuick 2.0
import Ubuntu.Components 1.1
import Ubuntu.Content 0.1
import Ubuntu.Components.Popups 1.0
import Ubuntu.Components.ListItems 1.0 as ListItem

FlowListView {
    id: rootItem

    width: parent.width
    spacing: units.gu(1)
    clip: true

    property int delegateWidth: units.gu(8)
    property int delegateHeight: delegateWidth

    signal picsModelChanged()

    function importImageFromContentHub() {
        rootItem.activeTransfer = picSource.request(appStore);
    }

    model: ListModel {
        id: picModel
    }

    delegate: AbstractButton {
        id: picDelegate

        height: rootItem.delegateHeight
        width: rootItem.delegateWidth

        UbuntuShape {
            id: delegateShape
            anchors.fill: parent
            clip: true

            image: Image {
                source: "image://thumbnailer/" + Qt.resolvedUrl(model.url)
                fillMode: Image.PreserveAspectCrop
            }
        }

        onPressedChanged: {
            if (pressed)
                delegateShape.borderSource = "radius_pressed.sci"
            else
                delegateShape.borderSource = "radius_idle.sci"
        }

        onClicked: pageStack.push(Qt.resolvedUrl("./ImageViewer.qml"), {source: Qt.resolvedUrl(model.url)})
        onPressAndHold: {
            rootItem.currentIndex = model.index
            PopupUtils.open(pictureMenuPopover, rootItem.currentItem)
        }

        // *** PICTURE POPOVER ***
        Component {
            id: pictureMenuPopover
            Popover {
                id: popover
                Column {
                    anchors { left: parent.left; top: parent.top; right: parent.right }

                    ListItem.Standard {
                        text: i18n.tr("Remove picture from selection")
                        onClicked: {
                            PopupUtils.close(popover)
                            rootItem.model.remove(rootItem.currentIndex)
                            rootItem.picsModelChanged()
                        }
                    }
                }
            }
        }
    }

    footerComponent: Component {
        Item {
            height: rootItem.delegateHeight
            width: rootItem.delegateWidth

            AbstractButton {
                id: addButton

                anchors.right: parent.right
                height: parent.height
                width: height

                UbuntuShape {
                    id: footerShape
                    anchors.fill: parent
                    clip: true

                    Icon {
                        anchors.centerIn: parent
                        height: parent.height / 2
                        width: height
                        name: "add"
                    }
                }

                onPressedChanged: {
                    if (pressed)
                        footerShape.borderSource = "radius_pressed.sci"
                    else
                        footerShape.borderSource = "radius_idle.sci"
                }

                onClicked: importImageFromContentHub()
            }
        }
    }

    function exportModel() {
        var list = []
        for (var i=0; i<picModel.count; i++) {
            list[i] = picModel.get(i)
        }

        return list
    }


    // *** CONTENT HANDLER ***
    property var activeTransfer

    ContentPeer {
        id: picSource
        contentType: ContentType.Pictures
        handler: ContentHandler.Source
        selectionType: ContentTransfer.Multiple
    }

    ContentTransferHint {
        id: transferHint
        anchors.fill: parent
        activeTransfer: rootItem.activeTransfer
    }

    ContentStore {
        id: appStore
        scope: ContentScope.App
    }

    Connections {
        target: rootItem.activeTransfer ? rootItem.activeTransfer : null
        onStateChanged: {
            if (rootItem.activeTransfer.state === ContentTransfer.Charged) {
                for (var i=0; i<rootItem.activeTransfer.items.length; i++) {
                    picModel.append({url: rootItem.activeTransfer.items[i].url.toString().replace("file://", "")})
                    console.log("CONTENT IMPORTED:", rootItem.activeTransfer.items[i].url.toString().replace("file://", ""))
                    rootItem.picsModelChanged()
                }
            }
        }
    }
}
